@@ -14,6 +14,10 @@
 #' @param suffix Character string to append to each label. Default is `""`.
 #' @param magnitude_only Logical. If `TRUE`, shows only the power-of-10 part
 #'   (e.g., \eqn{10^5} instead of \eqn{1\times 10^5}). Default is `FALSE`.
+#' @param mult_sign Character string specifying the multiplication sign to use.
+#'   Either `"times"` (default, displays as \eqn{1.5 \times 10^3}) or `"cdot"`
+#'   (displays as \eqn{1.5 \cdot 10^3}). Caution: One some operation systems,
+#'   the `"times"` symbol is rendered as `"cdot"`.
 #' @param ... Additional arguments passed to [`scales::scientific()`].
 #'
 #' @return A label function that takes a numeric vector and returns an expression
@@ -66,8 +70,36 @@
 #'   scale_y_log10(labels = label_power10(magnitude_only = TRUE))
 #'
 #' @export
-label_power10 <- function(decimal.mark = NULL, digits = 3, scale = 1, prefix = "", suffix = "", magnitude_only = FALSE, ...) {
-  force_all(decimal.mark, digits, scale, prefix, suffix, magnitude_only, ...)
+label_power10 <- function(decimal.mark = NULL, digits = 3, scale = 1, prefix = "", suffix = "",
+                          magnitude_only = FALSE, mult_sign = c("times", "cdot"), ...) {
+  force_all(decimal.mark, digits, scale, prefix, suffix, magnitude_only, mult_sign, ...)
+
+  # Check for ggplot2 4.0.0 bug with expressions in scale labels
+  # https://github.com/tidyverse/ggplot2/issues/6617
+  # Skip warning during tests to avoid test failure
+  ggplot2_version <- utils::packageVersion("ggplot2")
+  is_testing <- identical(Sys.getenv("TESTTHAT"), "true")
+
+  if (ggplot2_version == "4.0.0" && !is_testing) {
+    cli::cli_warn(
+      c(
+        "!" = "ggplot2 version 4.0.0 has a bug when using expressions in scale labels.",
+        "i" = "This may cause the error '`breaks` and `labels` have different lengths.`' with {.fn label_power10}.",
+        "i" = "Please update to ggplot2 >= 4.0.1 or downgrade to 3.5.2.",
+        "i" = "See: {.url https://github.com/tidyverse/ggplot2/issues/6617}"
+      ),
+      .frequency = "once",
+      .frequency_id = "ggsurveillance_ggplot2_4.0.0_bug"
+    )
+  }
+
+  mult_sign <- rlang::arg_match(mult_sign)
+
+  mult_sign <- case_when(
+    mult_sign == "times" ~ " %*% ",
+    mult_sign == "cdot" ~ " %.% ",
+    .default = " %*% ", .ptype = character(0)
+  )
 
   function(x) {
     decimal.mark <- decimal.mark %||% getOption("scales.decimal.mark", default = ".")
@@ -102,12 +134,13 @@ label_power10 <- function(decimal.mark = NULL, digits = 3, scale = 1, prefix = "
 
     # Formatting depending on exponent
     dplyr::case_when(
+      is.na(x) ~ NA_character_,
       magnitude_only & expn == 0 ~ paste0(sign, "1"),
       expn == 0 ~ mant,
       magnitude_only & expn == 1 ~ paste0(sign, "10"),
-      expn == 1 ~ paste0(mant, " %*% 10"),
+      expn == 1 ~ paste0(mant, mult_sign, "10"),
       magnitude_only & (expn > 1 | expn < 0) ~ paste0(sign, "10^", expn),
-      TRUE ~ paste0(mant, " %*% 10^", expn)
+      TRUE ~ paste0(mant, mult_sign, "10^", expn)
     ) |>
       # Wrap it in pre and suffix
       vapply(FUN = wrap, FUN.VALUE = character(1)) |>
