@@ -6,12 +6,13 @@ test_that("geom_epicurve handles basic date inputs", {
   )
 
   # Create plot
-  p <- ggplot(test_dates, aes(x = date, fill = cat)) +
+  p <- ggplot(test_dates, aes(x = date)) +
     geom_vline_year() +
-    geom_epicurve(date_resolution = "day") +
+    geom_epicurve(aes(fill = cat), date_resolution = "day") +
+    # Cave: ggplot 4.0.0 Bug, already fixed in 4.0.1
     geom_epicurve_point(aes(shape = cat), date_resolution = "day", vjust = 0.3) +
     geom_epicurve_text(aes(label = cat), date_resolution = "day", vjust = 0.8) +
-    stat_bin_date(aes(y = after_stat(count) * 1.05, label = after_stat(count)),
+    stat_bin_date(aes(y = after_stat(count) * 1.05, label = after_stat(count), group = 1),
       date_resolution = "day", geom = "text"
     ) +
     scale_y_cases_5er() +
@@ -24,6 +25,24 @@ test_that("geom_epicurve handles basic date inputs", {
   expect_no_error(p)
   vdiffr::expect_doppelganger("1_geom_epicurve_basic_date", p)
 
+  p0 <- ggplot(test_dates, aes(x = date, group = cat)) +
+    geom_vline_year() +
+    geom_epicurve(aes(fill = cat), date_resolution = "week") +
+    geom_epicurve_point(aes(shape = cat), date_resolution = "week", vjust = 0.3) +
+    geom_epicurve_text(aes(label = cat), date_resolution = "week", vjust = 0.8) +
+    stat_bin_date(aes(y = after_stat(count) * 1.05, label = after_stat(count), group = 1),
+      date_resolution = "week", geom = "text", position = "stack"
+    ) +
+    scale_y_cases_5er() +
+    theme_mod_legend_position(position.inside = c(0.5, 0.5)) +
+    theme_mod_rotate_x_axis_labels_90() +
+    theme_mod_remove_panel_grid()
+
+  expect_s3_class(p0, "ggplot")
+  expect_no_error(p0)
+  vdiffr::expect_doppelganger("1_geom_epicurve_basic_week", p0)
+
+
   p1 <- ggplot(test_dates, aes(x = date, fill = cat)) +
     geom_epicurve()
 
@@ -206,7 +225,7 @@ test_that("stat_bin_date: test fill_gaps", {
   p1_1 <- ggplot(plot_data_epicurve_imp, aes(x = date, weight = 2)) +
     stat_bin_date(date_resolution = "week") +
     scale_y_cases_5er(limits = NULL)
-  expect_no_error(p1)
+  expect_no_error(p1_1)
   vdiffr::expect_doppelganger("8_stat_bin_date_base", p1_1)
 
   p2 <- ggplot(plot_data_epicurve_imp, aes(x = date, weight = 2)) +
